==> ogre-14.3.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_compositor_manager.js <==
var class_ogre_1_1_compositor_manager =
[
    [ "UniqueTextureSet", "class_ogre_1_1_compositor_manager.html#a412c661642f90327cc59eea475194b81", null ],
    [ "CompositorManager", "class_ogre_1_1_compositor_manager.html#aeb2dde02f0631082a73fafcff189f3d7", null ],
    [ "~CompositorManager", "class_ogre_1_1_compositor_manager.html#ac758255395ad3b00bea001aa0aaf88d6", null ],
    [ "create", "class_ogre_1_1_compositor_manager.html#aa8e6e8df0d1413256a0b961fe929eab7", null ],
    [ "getByName", "class_ogre_1_1_compositor_manager.html#a774da533de0e9dc7263551a37136a2c6", null ],
    [ "getCompositorChain", "class_ogre_1_1_compositor_manager.html#aa9897c6f8287aee48aa96e7ffcf29de5", null ],
    [ "hasCompositorChain", "class_ogre_1_1_compositor_manager.html#aa4fc21a9b8393b670c732dfbfa0e7577", null ],
    [ "removeCompositorChain", "class_ogre_1_1_compositor_manager.html#a5d3c650de250cd3cb66484730fd4f95a", null ],
    [ "addCompositor", "class_ogre_1_1_compositor_manager.html#ab3f3a6e9ea6abe6edbb428613a8b866a", null ],
    [ "removeCompositor", "class_ogre_1_1_compositor_manager.html#a95a06faa7dac1be13f90b723ed8fa625", null ],
    [ "setCompositorEnabled", "class_ogre_1_1_compositor_manager.html#a40c9604cabf06d767110f4c2d73cf65d", null ],
    [ "_getTexturedRectangle2D", "class_ogre_1_1_compositor_manager.html#abc22280b859b4f57bb71a63374c36032", null ],
    [ "removeAll", "class_ogre_1_1_compositor_manager.html#a40feb1956c7edd68fd65835a44db84b0", null ],
    [ "_reconstructAllCompositorResources", "class_ogre_1_1_compositor_manager.html#a5cc7bae199f7984d34f725c7d0d255fb", null ],
    [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#ac6daf1c536921b05c05a172a6a2b466f", null ],
    [ "freePooledTextures", "class_ogre_1_1_compositor_manager.html#a1ac07452c980fbcb7445346b4ff329bf", null ],
    [ "registerCompositorLogic", "class_ogre_1_1_compositor_manager.html#a9c7d4168d56868599badb2789d54157c", null ],
    [ "unregisterCompositorLogic", "class_ogre_1_1_compositor_manager.html#aa7da6f02251d1e14ee50dcb1591e391c", null ],
    [ "getCompositorLogic", "class_ogre_1_1_compositor_manager.html#a19e9fac87ffda184125510157b6d48ff", null ],
    [ "hasCompositorLogic", "class_ogre_1_1_compositor_manager.html#a25c528930841cdf825aa359850bd7788", null ],
    [ "registerCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#ae9b8ca4c2a51c0720bb31393d20fe7c9", null ],
    [ "unregisterCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#a7abff0df9bc7cdd96cb730f8baad7f04", null ],
    [ "getCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#a31073e01284c78ef183f8eba087aa9c1", null ],
    [ "hasCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#ad41f67cec0ec695f3e29263de4003d2f", null ],
    [ "_relocateChain", "class_ogre_1_1_compositor_manager.html#a31474f0e4d6485437c1cb856923d4499", null ],
    [ "getSingleton", "class_ogre_1_1_compositor_manager.html#a14161d8b081fa94f9caae3a0473d08db", null ],
    [ "getSingletonPtr", "class_ogre_1_1_compositor_manager.html#a58f71f164aff7d56b1f2c563522b651a", null ]
];

==> ogre-14.5.2-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_compositor_manager.js <==
var class_ogre_1_1_compositor_manager =
[
    [ "UniqueTextureSet", "class_ogre_1_1_compositor_manager.html#a412c661642f90327cc59eea475194b81", null ],
    [ "CompositorManager", "class_ogre_1_1_compositor_manager.html#aeb2dde02f0631082a73fafcff189f3d7", null ],
    [ "~CompositorManager", "class_ogre_1_1_compositor_manager.html#ac758255395ad3b00bea001aa0aaf88d6", null ],
    [ "create", "class_ogre_1_1_compositor_manager.html#aa8e6e8df0d1413256a0b961fe929eab7", null ],
    [ "getByName", "class_ogre_1_1_compositor_manager.html#a774da533de0e9dc7263551a37136a2c6", null ],
    [ "getCompositorChain", "class_ogre_1_1_compositor_manager.html#aa9897c6f8287aee48aa96e7ffcf29de5", null ],
    [ "hasCompositorChain", "class_ogre_1_1_compositor_manager.html#aa4fc21a9b8393b670c732dfbfa0e7577", null ],
    [ "removeCompositorChain", "class_ogre_1_1_compositor_manager.html#a5d3c650de250cd3cb66484730fd4f95a", null ],
    [ "addCompositor", "class_ogre_1_1_compositor_manager.html#ab3f3a6e9ea6abe6edbb428613a8b866a", null ],
    [ "removeCompositor", "class_ogre_1_1_compositor_manager.html#a95a06faa7dac1be13f90b723ed8fa625", null ],
    [ "setCompositorEnabled", "class_ogre_1_1_compositor_manager.html#a40c9604cabf06d767110f4c2d73cf65d", null ],
    [ "_getTexturedRectangle2D", "class_ogre_1_1_compositor_manager.html#abc22280b859b4f57bb71a63374c36032", null ],
    [ "removeAll", "class_ogre_1_1_compositor_manager.html#a40feb1956c7edd68fd65835a44db84b0", null ],
    [ "_reconstructAllCompositorResources", "class_ogre_1_1_compositor_manager.html#a5cc7bae199f7984d34f725c7d0d255fb", null ],
    [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#a13a596ef6964a68dc25e9858b2201d26", null ],
    [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#ac6daf1c536921b05c05a172a6a2b466f", null ],
    [ "freePooledTextures", "class_ogre_1_1_compositor_manager.html#a1ac07452c980fbcb7445346b4ff329bf", null ],
    [ "registerCompositorLogic", "class_ogre_1_1_compositor_manager.html#a9c7d4168d56868599badb2789d54157c", null ],
    [ "unregisterCompositorLogic", "class_ogre_1_1_compositor_manager.html#aa7da6f02251d1e14ee50dcb1591e391c", null ],
    [ "getCompositorLogic", "class_ogre_1_1_compositor_manager.html#a19e9fac87ffda184125510157b6d48ff", null ],
    [ "hasCompositorLogic", "class_ogre_1_1_compositor_manager.html#a25c528930841cdf825aa359850bd7788", null ],
    [ "registerCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#ae9b8ca4c2a51c0720bb31393d20fe7c9", null ],
    [ "unregisterCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#a7abff0df9bc7cdd96cb730f8baad7f04", null ],
    [ "getCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#a31073e01284c78ef183f8eba087aa9c1", null ],
    [ "hasCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#ad41f67cec0ec695f3e29263de4003d2f", null ],
    [ "_relocateChain", "class_ogre_1_1_compositor_manager.html#a31474f0e4d6485437c1cb856923d4499", null ],
    [ "getSingleton", "class_ogre_1_1_compositor_manager.html#a14161d8b081fa94f9caae3a0473d08db", null ],
    [ "getSingletonPtr", "class_ogre_1_1_compositor_manager.html#a58f71f164aff7d56b1f2c563522b651a", null ]
];
